# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['integratethis']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['integratethis = integratethis:main']}

setup_kwargs = {
    'name': 'integratethis',
    'version': '2024.6.23.1',
    'description': 'Integrate programs or scripts into common tools like Windows Explorer context menu',
    'long_description': '* integratethis\n\nThis tool integrates other tools in common programs.\n\nFor example, I wrote some awesome Python command line tools such as\n[[https://github.com/novoid/filetags][filetags]], [[https://github.com/novoid/date2name][date2name]], or [[https://github.com/novoid/appendfilename][appendfilename]]. Once installed via =pip\ninstall=, they can only be used on the command line such as =cmd.exe=\nor a shell.\n\nTo install all the supported tools, use the following command:\n\n: pip install date2name appendfilename filetags integratethis\n\nUsing this tool, I can integrate them for example to the "Send to"\ncontext menu of the Windows Explorer using commands like:\n\n: integratethis date2name\n: integratethis time2name\n: integratethis appendfilename --confirm\n: integratethis filetags --confirm\n: integratethis filetags --parameter="--filter" --displayname "filetags filter"\n: integratethis filetags --parameter="--filter --recursive" --displayname "filetags filter recursive"\n: integratethis filetags --parameter="--tagtrees --recursive --tagtrees-handle-no-tag no-tags" --displayname "TagTrees recursive"\n: integratethis filetags --parameter="--tagtrees --tagtrees-depth 3" --displayname "TagTrees lvl3"\n\nNote that =integratethis time2name= is a shortcut for:\n\n: integratethis date2name  --parameter="--withtime %*" --displayname "time2name"\n\nOf course, you can remove the commands using the =--delete= parameter\nas well.\n\n- *Target group*: users who are fine to use command line tools\n- Hosted on github: [[https://github.com/novoid/integratethis]]\n\n** Installation\n\nThis tool needs [[http://www.python.org/downloads/][Python 3 to be installed]].\n\nYou can install filetags either via [[https://packaging.python.org/tutorials/installing-packages/][pip]] which is the recommended way.\nOr you can install filetags using the source code, e.g., by cloning\nthe [[https://github.com/novoid/integratethis][GitHub repository of integratethis]].\n\n*** Installation Via Pip\n\nIf you have installed Python 2 and Python 3 in parallel, make sure to\nuse the correct pip version. You might need to use =pip3= instead of\n=pip=. If you only have Python 3 installed, you don\'t have to care ;-)\n\nOn Microsoft Windows (only), you are going to need ~pip install\npypiwin32~ as prerequisite.\n\nNow install filetags via [[https://pip.pypa.io/en/stable/][pip]]: ~pip install integratethis~\n\nYou get updates by executing the very same pip command again.\n\n*** Installation Via Source Code\n\nIf you use the GitHub sources (and not pip), the executable is\n~integratethis/__init__.py~. You might want to create a (symbolic) link named\n"integratethis" to that file.\n\n** Usage\n\n # #+BEGIN_SRC sh :results output :wrap src\n # python3 ./integratethis/__init__.py --help\n # #+END_SRC\n\n#+BEGIN_src\nusage: integratethis [-h] [--overwrite] [--parameter PARAMETERS]\n                     [--confirm] [--into PROGRAM]\n                     [--displayname DISPLAYNAME] [--delete] [-v]\n                     [-q]\n                     command\n\nThis program integrates arbitrary commands to various tools.\nFor example, you can add a program named "filetags" to the "Send to"\nfolder of the context menu of the Windows File explorer via\n    integratethis filetags\n\nThe integration method used differs from tool to tool. For the Windows Explorer,\na batch file is placed within the AppData\\Roaming folder in case of additional\nparameters have to be added to the command and a lnk file to it is created in\nthe "Send to" folder so that you can use the command from the context menu of\nthe Windows Exporer. If no additional parameters are required, a lnk file to the\ncommand itself is placed in the "Send to" folder. For details, please look at\nthe source code or read the help info for the --into parameter.\n\nYou can overwrite pre-configured parameters using the command line options.\n\npositional arguments:\n  command               The command to integrate. For a defined set of tools\n                        which can be installed via "pip3 install", parameters\n                        are pre-configured: filetags, appendfilename,\n                        date2name, time2name (date2name but with time-stamp),\n                        and more to come in the future. The path for the\n                        command is looked up using "where" (Windows) or\n                        "which" (all other operating systems) so that the\n                        command has to be found in the path of the current\n                        environment.\n\noptional arguments:\n  -h, --help            show this help message and exit\n  --overwrite           Do not warn when a previous batch- or lnk-file for\n                        integration get overwritten.\n  --parameter PARAMETERS\n                        Optional parameter string which replaces any pre-\n                        defined parameter set and gets appended after the\n                        command when being invoked. For example, \'filetags\' as\n                        this pre-configured to "--interactive *" (on non-\n                        Windows) in order to use the interactive mode and\n                        operate on all selected files. Since this parameter\n                        replaces pre-defined parameter sets, you have to make\n                        sure to include \'%*\' (Windows) or \'"${*}"\' (non-\n                        Windows) if you need to process marked files.\n  --confirm             Ask the user to confirm by pressing RETURN/ENTER\n                        before closing the dialog window of the batch file to\n                        run the command.\n  --into PROGRAM        Explicitely define, where to integrate the program to.\n                        Valid values (according to your operating system) are:\n                        windowsexplorer (same as File Explorer; default for\n                        Windows), and more to come in future.\n  --displayname DISPLAYNAME\n                        Optional name that should be used instead of the\n                        command name when being linked.\n  --delete              Instead of integrate the program, remove its\n                        integration. Command or displayname has to match the\n                        existing integration point.\n  -v, --verbose         enable verbose mode\n  -q, --quiet           enable quiet mode\n\n:copyright: (c) by Karl Voit <tools@Karl-Voit.at>\n:license: GPL v3 or any later version\n:URL: https://github.com/novoid/integratethis\n:bugreports: via github or <tools@Karl-Voit.at>\n:version: 2019-10-29\n·\n#+END_src\n\n\n** Changelog\n\n- 2018-04-25: initial version\n- 2019-10-29: bugfix version\n\n* Related tools and workflows\n\nThis tool is part of a tool-set which I use to manage my digital files\nsuch as photographs. My work-flows are described in [[http://karl-voit.at/managing-digital-photographs/][this blog posting]]\nyou might like to read.\n\nIn short:\n\nFor *tagging*, please refer to [[https://github.com/novoid/filetags][filetags]] and its documentation.\n\nSee [[https://github.com/novoid/date2name][date2name]] for easily adding ISO *time-stamps or date-stamps* to\nfiles.\n\nFor *easily naming and tagging* files within file browsers that allow\nintegration of external tools, see [[https://github.com/novoid/appendfilename][appendfilename]] (once more) and\n[[https://github.com/novoid/filetags][filetags]].\n\nMoving to the archive folders is done using [[https://github.com/novoid/move2archive][move2archive]].\n\nHaving tagged photographs gives you many advantages. For example, I\nautomatically [[https://github.com/novoid/set_desktop_background_according_to_season][choose my *desktop background image* according to the\ncurrent season]].\n\nFiles containing an ISO time/date-stamp gets indexed by the\nfilename-module of [[https://github.com/novoid/Memacs][Memacs]].\n\n* How to Thank Me\n\nI\'m glad you like my tools. If you want to support me:\n\n- Send old-fashioned *postcard* per snailmail - I love personal feedback!\n  - see [[http://tinyurl.com/j6w8hyo][my address]]\n- Send feature wishes or improvements as an issue on GitHub\n- Create issues on GitHub for bugs\n- Contribute merge requests for bug fixes\n- Check out my other cool [[https://github.com/novoid][projects on GitHub]]\n\n* Local Variables                                                  :noexport:\n# Local Variables:\n# mode: auto-fill\n# mode: flyspell\n# eval: (ispell-change-dictionary "en_US")\n# End:\n',
    'author': 'Karl Voit',
    'author_email': 'tools@Karl-Voit.at',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)
